@@ -61,6 +61,7 @@ expr1 =  choice [
   , unary
   , binary
   , enclosure
+  , bareSubSup
   , environment
   , diacritical
   , escaped
@@ -88,6 +89,10 @@ expr = do
   limits <- limitsIndicator
   subSup limits a <|> superOrSubscripted limits a <|> return a
 
+bareSubSup :: TP Exp
+bareSubSup = subSup Nothing (EIdentifier "")
+  <|> superOrSubscripted Nothing (EIdentifier "")
+
 limitsIndicator :: TP (Maybe Bool)
 limitsIndicator =
    try (symbol "\\limits" >> return (Just True))
@@ -428,11 +433,23 @@ binary = try $ do
 
 texSymbol :: TP Exp
 texSymbol = try $ do
+  negated <- (try (symbol "\\not") >> return True) <|> return False
   sym <- operator <|> command
   case M.lookup sym symbols of
-       Just s   -> return s
+       Just s   -> if negated then neg s else return s
        Nothing  -> pzero
 
+neg :: Exp -> TP Exp
+neg (ESymbol Rel x) = ESymbol Rel `fmap`
+  case x of
+       "\x2282" -> return "\x2284"
+       "\x2283" -> return "\x2285"
+       "\x2286" -> return "\x2288"
+       "\x2287" -> return "\x2289"
+       "\x2208" -> return "\x2209"
+       _        -> pzero
+neg _ = pzero
+
 -- The lexer
 lexer :: P.TokenParser st
 lexer = P.makeTokenParser texMathDef
@@ -632,6 +649,10 @@ symbols = M.fromList [
            , ("\\supset", ESymbol Rel "\x2283")
            , ("\\subseteq", ESymbol Rel "\x2286")
            , ("\\supseteq", ESymbol Rel "\x2287")
+           , ("\\nsubset", ESymbol Rel "\x2284")
+           , ("\\nsupset", ESymbol Rel "\x2285")
+           , ("\\nsubseteq", ESymbol Rel "\x2288")
+           , ("\\nsupseteq", ESymbol Rel "\x2289")
            , ("\\sqsubset", ESymbol Rel "\x228F")
            , ("\\sqsupset", ESymbol Rel "\x2290")
            , ("\\sqsubseteq", ESymbol Rel "\x2291")
